﻿using System;
using System.Windows.Forms;

using Arction.WinForms.Charting;
using Arction.WinForms.Charting.Axes;
using Arction.WinForms.Charting.SeriesXY;
using Arction.WinForms.Charting.Views.ViewXY;

namespace TestProject
{
    /// <summary>
    /// 메인 폼
    /// </summary>
    public partial class MainForm : Form
    {
        //////////////////////////////////////////////////////////////////////////////////////////////////// Field
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region Field

        /// <summary>
        /// 차트
        /// </summary>
        private LightningChartUltimate chart = null;

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Constructor
        ////////////////////////////////////////////////////////////////////////////////////////// Public

        #region 생성자 - MainForm()

        /// <summary>
        /// 생성자
        /// </summary>
        public MainForm()
        {
            InitializeComponent();

            InitializeChart();
        }

        #endregion

        //////////////////////////////////////////////////////////////////////////////////////////////////// Method
        ////////////////////////////////////////////////////////////////////////////////////////// Private

        #region 차트 초기화하기 - InitializeChart()

        /// <summary>
        /// 차트 초기화하기
        /// </summary>
        private void InitializeChart()
        {
            this.chart = new LightningChartUltimate();
            
            this.chart.BeginUpdate();
            
            this.chart.Name   = "chart";
            this.chart.Parent = this;
            this.chart.Dock   = DockStyle.Fill;

            this.chart.Title.Font = Font;
            this.chart.Title.Text = "선/막대 차트";

            ViewXY viewXY = this.chart.ViewXY;

            AxisX axisX = viewXY.XAxes[0];

            axisX.Title.Font     = Font;
            axisX.Title.Text     = "X축";
            axisX.ValueType      = AxisValueType.Number;
            axisX.ScrollMode     = XAxisScrollMode.None;
            axisX.AutoDivSpacing = false;
            axisX.MajorDiv       = 2;

            axisX.SetRange(0, 10);

            AxisY axisY = viewXY.YAxes[0];

            axisY.Title.Font = Font;
            axisY.Title.Text = "Y축";

            axisY.SetRange(0, 50);

            ChartHelper.SetDarkFlatStyle(this.chart);

            int pointCount = 101;

            const double INTERVAL = 0.1;

            double[] xValueArray = new double[pointCount];
            double[] yValueArray = new double[pointCount];

            for(int i = 0; i < pointCount; i++)
            {
                xValueArray[i] = (double)i * INTERVAL;
                yValueArray[i] = 30.0 + 5.0 * Math.Sin((double)i / 20.0);
            }

            yValueArray[40] = double.NaN;
            yValueArray[70] = double.NaN;
            yValueArray[71] = double.NaN;
            yValueArray[72] = double.NaN;
            yValueArray[73] = double.NaN;
            yValueArray[90] = double.NaN;
            yValueArray[91] = double.NaN;

            PointLineSeries series = new PointLineSeries(viewXY, axisX, axisY);

            series.DataBreaking.Enabled = true;
            series.DataBreaking.Value   = double.NaN;

            SeriesPoint[] pointArray = new SeriesPoint[pointCount];

            for(int i = 0; i < pointCount; i++)
            {
                pointArray[i].X = xValueArray[i];
                pointArray[i].Y = yValueArray[i];
            }

            series.Points = pointArray;

            viewXY.PointLineSeries.Add(series);

            LegendBoxXY legendBoxXY = viewXY.LegendBoxes[0];

            legendBoxXY.Visible = false;

            this.chart.EndUpdate();
        }

        #endregion
    }
}